
.. _sardana-devel-macro-plotting-examples:

=========================
Macro plotting examples
=========================

This chapter consists of a series of examples demonstrating how to plot graphics
from inside a macro.

The complete set of :mod:`~matplotlib.pyplot` examples can be found
:ref:`here <examples-index>`


.. literalinclude:: ../../../../src/sardana/macroserver/macros/examples/plotting.py
   :language: python
   :linenos:
